==> ViennaRNA-2.4.14.tar.gz: ViennaRNA-2.4.14/doc/html/group__part__func__global.js <==
var group__part__func__global =
[
    [ "Computing Partition Functions of a Distance Based Partitioning", "group__kl__neighborhood__pf.html", "group__kl__neighborhood__pf" ],
    [ "Deprecated Interface for Global Partition Function Computation", "group__part__func__global__deprecated.html", "group__part__func__global__deprecated" ],
    [ "part_func.h", "part__func_8h.html", null ],
    [ "vrna_dimer_pf_s", "group__part__func__global.html#structvrna__dimer__pf__s", [
      [ "F0AB", "group__part__func__global.html#a82e31d1fb6e95923fab6036f52c370af", null ],
      [ "FAB", "group__part__func__global.html#a01a87f59db2b7fbf883b056e6f6c673a", null ],
      [ "FcAB", "group__part__func__global.html#a7b01cea5721f61badebc29cf0a9c4266", null ],
      [ "FA", "group__part__func__global.html#a1aca57247f2c023d08028b1919005b0a", null ],
      [ "FB", "group__part__func__global.html#ab4d307be5400604d3c1d84d58a9981df", null ]
    ] ],
    [ "vrna_mean_bp_distance_pr", "group__part__func__global.html#gad3f0c240512e6d43e2e4d4c2076021f5", null ],
    [ "vrna_mean_bp_distance", "group__part__func__global.html#gaa6b8983b559b9ef4b2e1b31113ea317b", null ],
    [ "vrna_ensemble_defect", "group__part__func__global.html#gaaf197722d1faa86af5e7b4240acafdee", null ],
    [ "vrna_stack_prob", "group__part__func__global.html#ga132664bf29fdc30bb5ea715491d1ab22", null ],
    [ "vrna_pf_dimer_probs", "group__part__func__global.html#gaa1e39e73afb51fbaf4ae38f0c066c46b", null ],
    [ "vrna_pr_structure", "group__part__func__global.html#ga882c35d9dd775c1275593b3b6a966bec", null ],
    [ "vrna_pf", "group__part__func__global.html#ga29e256d688ad221b78d37f427e0e99bc", null ],
    [ "vrna_pf_dimer", "group__part__func__global.html#ga4e5c7d06c302a7c59fc0d64dc142ca63", null ],
    [ "vrna_pf_fold", "group__part__func__global.html#gac4a2a74a79e49818bc35412a2b392c7e", null ],
    [ "vrna_pf_circfold", "group__part__func__global.html#ga87e5a77b6e50dd54e9d032a9b92973be", null ],
    [ "vrna_pf_alifold", "group__part__func__global.html#ga374e31a0f326b2c5da5b84e143a63f38", null ],
    [ "vrna_pf_circalifold", "group__part__func__global.html#gab70fe6c9a78b79cc5669881720926e1d", null ],
    [ "vrna_plist_from_probs", "group__part__func__global.html#ga94f6efc0b8d8712b023452794a0a5bd2", null ],
    [ "vrna_positional_entropy", "group__part__func__global.html#ga4ec346141028c7bcd15bc235c408b6e9", null ],
    [ "vrna_pf_co_fold", "group__part__func__global.html#gaf2b846f7ac382686f35ff7b9202fdd5c", null ]
];

==> ViennaRNA-2.4.17.tar.gz: ViennaRNA-2.4.17/doc/html/group__part__func__global.js <==
var group__part__func__global =
[
    [ "Computing Partition Functions of a Distance Based Partitioning", "group__kl__neighborhood__pf.html", "group__kl__neighborhood__pf" ],
    [ "Predicting various thermodynamic properties", "group__thermodynamics.html", "group__thermodynamics" ],
    [ "Deprecated Interface for Global Partition Function Computation", "group__part__func__global__deprecated.html", "group__part__func__global__deprecated" ],
    [ "part_func.h", "part__func_8h.html", null ],
    [ "vrna_dimer_pf_s", "group__part__func__global.html#structvrna__dimer__pf__s", [
      [ "F0AB", "group__part__func__global.html#a82e31d1fb6e95923fab6036f52c370af", null ],
      [ "FAB", "group__part__func__global.html#a01a87f59db2b7fbf883b056e6f6c673a", null ],
      [ "FcAB", "group__part__func__global.html#a7b01cea5721f61badebc29cf0a9c4266", null ],
      [ "FA", "group__part__func__global.html#a1aca57247f2c023d08028b1919005b0a", null ],
      [ "FB", "group__part__func__global.html#ab4d307be5400604d3c1d84d58a9981df", null ]
    ] ],
    [ "vrna_pf", "group__part__func__global.html#ga29e256d688ad221b78d37f427e0e99bc", null ],
    [ "vrna_pf_dimer", "group__part__func__global.html#ga4e5c7d06c302a7c59fc0d64dc142ca63", null ],
    [ "vrna_pf_fold", "group__part__func__global.html#gac4a2a74a79e49818bc35412a2b392c7e", null ],
    [ "vrna_pf_circfold", "group__part__func__global.html#ga87e5a77b6e50dd54e9d032a9b92973be", null ],
    [ "vrna_pf_alifold", "group__part__func__global.html#ga374e31a0f326b2c5da5b84e143a63f38", null ],
    [ "vrna_pf_circalifold", "group__part__func__global.html#gab70fe6c9a78b79cc5669881720926e1d", null ],
    [ "vrna_plist_from_probs", "group__part__func__global.html#ga94f6efc0b8d8712b023452794a0a5bd2", null ],
    [ "vrna_pf_co_fold", "group__part__func__global.html#gaf2b846f7ac382686f35ff7b9202fdd5c", null ]
];
